==> open-xchange-core_7.8.3.orig.tar.bz2: open-xchange-core-7.8.3/com.openexchange.search/src/com/openexchange/search/internal/operands/AttachmentOperand.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.search.internal.operands;

import com.openexchange.search.Operand;

/**
 * {@link AttachmentOperand}
 *
 * @author <a href="mailto:kevin.ruthmann@open-xchange.com">Kevin Ruthmann</a>
 * @since v7.8.2
 */
public class AttachmentOperand implements Operand<String> {

    public enum AttachmentOperandType {
        NAME
    }

    private final AttachmentOperandType type;

    /**
     * Initializes a new {@link ColumnOperand}.
     *
     * @param name The attachment
     */
    public AttachmentOperand(final AttachmentOperandType type) {
        super();
        this.type = type;
    }

    @Override
    public com.openexchange.search.Operand.Type getType() {
        return Type.ATTACHMENT;
    }

    @Override
    public String getValue() {
        return type.toString();
    }

    @Override
    public String toString() {
        return new StringBuilder(Type.ATTACHMENT.getType()).append(':').append(type).toString();
    }

}

==> open-xchange-core_7.10.1.orig.tar.bz2: open-xchange-core-7.10.1/com.openexchange.search/src/com/openexchange/search/internal/operands/AttachmentOperand.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.search.internal.operands;

import java.util.Map;
import com.google.common.collect.ImmutableMap;
import com.openexchange.java.Strings;
import com.openexchange.search.Operand;

/**
 * {@link AttachmentOperand}
 *
 * @author <a href="mailto:kevin.ruthmann@open-xchange.com">Kevin Ruthmann</a>
 * @since v7.8.2
 */
public class AttachmentOperand implements Operand<String> {

    public static enum AttachmentOperandType {
        NAME("name");

        private final String name;

        private AttachmentOperandType(String name) {
            this.name = name;
        }

        private static final Map<String, AttachmentOperandType> TYPES_BY_NAME;
        static {
            ImmutableMap.Builder<String, AttachmentOperandType> typesByName = ImmutableMap.builder();
            for (AttachmentOperandType type : AttachmentOperandType.values()) {
                typesByName.put(type.name, type);
            }
            TYPES_BY_NAME = typesByName.build();
        }

        /**
         * Gets an {@link AttachmentOperandType} by its name.
         *
         * @return The type or <code>null</code>, if the name is invalid or unknown.
         */
        public static AttachmentOperandType getByName(String name) {
            return Strings.isEmpty(name) ? null : TYPES_BY_NAME.get(Strings.asciiLowerCase(name).trim());
        }
    }

    // -----------------------------------------------------------------------------------------------

    private final AttachmentOperandType type;

    /**
     * Initializes a new {@link ColumnOperand}.
     *
     * @param name The attachment
     */
    public AttachmentOperand(final AttachmentOperandType type) {
        super();
        this.type = type;
    }

    @Override
    public com.openexchange.search.Operand.Type getType() {
        return Type.ATTACHMENT;
    }

    @Override
    public String getValue() {
        return type.toString();
    }

    @Override
    public String toString() {
        return new StringBuilder(Type.ATTACHMENT.getType()).append(':').append(type).toString();
    }

}
